        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 34 <strong>control</strong><br>0,2,4,5,6,7,8,10,11,12,14,16,17,18,20,21,22,24,25,27,28,30,31,32,33,34,35,38,42,43,45,47,48,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 17 <br>1,3,9,13,15,19,23,26,29,36,37,39,40,41,44,46,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 34 <strong>control</strong><br>0,2,4,5,6,7,8,10,11,12,14,16,17,18,20,21,22,24,25,27,28,30,31,32,33,34,35,38,42,43,45,47,48,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 17 <br>1,3,9,13,15,19,23,26,29,36,37,39,40,41,44,46,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 34 <strong>control</strong><br>0,2,4,5,6,7,8,10,11,12,14,16,17,18,20,21,22,24,25,27,28,30,31,32,33,34,35,38,42,43,45,47,48,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 17 <br>1,3,9,13,15,19,23,26,29,36,37,39,40,41,44,46,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 34 <strong>control</strong><br>0,2,4,5,6,7,8,10,11,12,14,16,17,18,20,21,22,24,25,27,28,30,31,32,33,34,35,38,42,43,45,47,48,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 17 <br>1,3,9,13,15,19,23,26,29,36,37,39,40,41,44,46,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 34 <strong>control</strong><br>0,2,4,5,6,7,8,10,11,12,14,16,17,18,20,21,22,24,25,27,28,30,31,32,33,34,35,38,42,43,45,47,48,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 17 <br>1,3,9,13,15,19,23,26,29,36,37,39,40,41,44,46,49';}
}
